# Delpinos RabbitMQ - Python

![GitHub repo size](https://img.shields.io/github/repo-size/delpinos/python-base?style=for-the-badge)
![GitHub language count](https://img.shields.io/github/languages/count/delpinos/python-base?style=for-the-badge)
![GitHub forks](https://img.shields.io/github/forks/delpinos/python-base?style=for-the-badge)
![GitHub open issues](https://img.shields.io/github/issues-raw/delpinos/python-base?style=for-the-badge)
![GitHub open pull requests](https://img.shields.io/github/issues-pr-raw/delpinos/python-base?style=for-the-badge)


> Base codes for creating python modules
